# Dataprocxy
Uses `gcloud` to set up a socksv5 proxy to the google cloud dataproc master node and opens a Chrome browser configured with this proxy to open pages of interest. Used experimentally at Spotify.

# Install
Installation through pip: `pip install dataprocxy` or alternatively, clone this repository then `pip install .`.

# Code of Conduct
This project adheres to the [Open Code of Conduct][code-of-conduct]. By participating, you are expected to honor this code.

[code-of-conduct]: https://github.com/spotify/code-of-conduct/blob/master/code-of-conduct.md
